==> monica-3.7.0p0.tgz: www/monica/resources/lang/de/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Wie war dein Tag? Einmal am Tag kannst du ihn bewerten.',
    'journal_come_back' => 'Danke. Morgen kannst du wieder deinen Tag bewerten.',
    'journal_description' => 'Hinweis: Das Journal zeigt sowohl manuelle Einträge, als auch Aktivitäten mit deinen Kontakten an. Manuelle Einträge kannst du hier löschen, Aktivitäten kannst du auf der jeweiligen Profilseite der beteiligten Person editieren oder löschen.',
    'journal_add' => 'Tagebucheintrag hinzufügen',
    'journal_edit' => 'Tagebucheintrag bearbeiten',
    'journal_empty' => 'Leeres Tagebuch',
    'journal_created_at' => 'Erstellt am {date}',
    'journal_created_automatically' => 'Autmatisch hinzugefügt',
    'journal_entry_type_journal' => 'Tagebucheintrag',
    'journal_entry_type_activity' => 'Aktivität',
    'journal_entry_rate' => 'Du hast deinen Tag bewertet',
    'journal_add_comment' => 'Möchtest du einen Kommentar hinzufügen (optional)?',
    'journal_show_comment' => 'Kommentar anzeigen',
    'entry_delete_success' => 'Der Tagebucheintrag wurde erfolgreich gelöscht.',
    'journal_add_title' => 'Titel (optional)',
    'journal_add_date' => 'Datum',
    'journal_add_post' => 'Eintrag',
    'journal_add_cta' => 'Speichern',
    'journal_blank_cta' => 'Schreibe deinen ersten Eintrag',
    'journal_blank_description' => 'Im Tagebuch kannst du deine Erlebnisse festhalten und dich später an sie erinnern.',
    'delete_confirmation' => 'Willst du diesen Eintrag wirklich löschen?',
];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/de/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Wie war dein Tag? Einmal am Tag kannst du ihn bewerten.',
    'journal_come_back' => 'Danke. Morgen kannst du wieder deinen Tag bewerten.',
    'journal_description' => 'Hinweis: Das Journal zeigt sowohl manuelle Einträge, als auch Aktivitäten mit deinen Kontakten an. Manuelle Einträge kannst du hier löschen, Aktivitäten kannst du auf der jeweiligen Profilseite der beteiligten Person editieren oder löschen.',
    'journal_add' => 'Tagebucheintrag hinzufügen',
    'journal_edit' => 'Tagebucheintrag bearbeiten',
    'journal_empty' => 'Leeres Tagebuch',
    'journal_created_at' => 'Erstellt am {date}',
    'journal_created_automatically' => 'Autmatisch hinzugefügt',
    'journal_entry_type_journal' => 'Tagebucheintrag',
    'journal_entry_type_activity' => 'Aktivität',
    'journal_entry_rate' => 'Du hast deinen Tag bewertet',
    'journal_add_comment' => 'Möchtest du einen Kommentar hinzufügen (optional)?',
    'journal_show_comment' => 'Kommentar anzeigen',
    'entry_delete_success' => 'Der Tagebucheintrag wurde erfolgreich gelöscht.',
    'journal_add_title' => 'Titel (optional)',
    'journal_add_date' => 'Datum',
    'journal_add_post' => 'Eintrag',
    'journal_add_cta' => 'Speichern',
    'journal_blank_cta' => 'Schreibe deinen ersten Eintrag',
    'journal_blank_description' => 'Im Tagebuch kannst du deine Erlebnisse festhalten und dich später an sie erinnern.',
    'delete_confirmation' => 'Willst du diesen Eintrag wirklich löschen?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
